/*
 * Copyright 2009 Keith Stevens 
 *
 * This file is part of the S-Space package and is covered under the terms and
 * conditions therein.
 *
 * The S-Space package is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation and distributed hereunder to you.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND NO REPRESENTATIONS OR WARRANTIES,
 * EXPRESS OR IMPLIED ARE MADE.  BY WAY OF EXAMPLE, BUT NOT LIMITATION, WE MAKE
 * NO REPRESENTATIONS OR WARRANTIES OF MERCHANT- ABILITY OR FITNESS FOR ANY
 * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE OR DOCUMENTATION
 * WILL NOT INFRINGE ANY THIRD PARTY PATENTS, COPYRIGHTS, TRADEMARKS OR OTHER
 * RIGHTS.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package edu.ucla.sspace.vector;


/**
 * An generalized interface for vectors.  This interface allows implementations
 * to implement the vector with any kind of underlying data type.
 * 
 * @author Keith Stevens
 */
public interface Vector<T extends Number> {

    /**
     * Returns {@code true} if the object is a {@link Vector} of the same length
     * and whose corresponding indices have equivalent values.
     */
    boolean equals(Object o);

    /**
     * Return the value of the vector at the given index as a {@code Number}.
     *
     * @param index index to retrieve.
     * @return value at index.
     */
    Number getValue(int index);

    /**
     * Returns the hash code as the sum of the vectors elements, normalized to
     * an {@code int}.
     */
    int hashCode();

    /**
     * Return the size of the {@code Vector}.
     *
     * @return size of the vector.
     */
    int length();

    /**
     * Returns the magnitude of this vector
     */
    double magnitude();

    /**
     * Set the value in the vector (optional operation).
     *
     * @param index index to set.
     * @param value value to set in the vector.
     */
    void set(int index, Number value);
}
